@@ -39,6 +39,8 @@ type Response struct {
 	Answers     []Answer    `json:"answers"`
 	Authorities []Authority `json:"authorities"`
 	Questions   []Question  `json:"questions"`
+	Additional  []Answer    `json:"additional,omitempty"`
+	Edns        *EdnsInfo   `json:"edns,omitempty"`
 }
 
 type Question struct {
@@ -69,6 +71,16 @@ type Authority struct {
 	Nameserver string `json:"nameserver"`
 }
 
+type EdnsInfo struct {
+	NSID         string `json:"nsid,omitempty"`
+	Cookie       string `json:"cookie,omitempty"`
+	Subnet       string `json:"subnet,omitempty"`
+	SubnetScope  uint8  `json:"subnet_scope,omitempty"`
+	ExtendedErr  string `json:"extended_error,omitempty"`
+	UDPSize      uint16 `json:"udp_size,omitempty"`
+	DNSSECOk     bool   `json:"dnssec_ok,omitempty"`
+}
+
 // LoadResolvers loads differently configured
 // resolvers based on a list of nameserver.
 func LoadResolvers(opts Options) ([]Resolver, error) {
